# Proxbox CLI Command Examples

Machine-generated help captures for representative `pxb` commands.

!!! info "Generated"
    Last updated: `2026-03-28T14:49:37.241515+00:00`

## Sections

- [Core Commands](./core-commands.md) — 4 captures
- [NetBox Commands](./netbox-commands.md) — 2 captures
- [Proxmox Commands](./proxmox-commands.md) — 3 captures
- [Infrastructure Commands](./infrastructure-commands.md) — 4 captures
